#!/bin/sh
# @(#) script to install internally numbered sse and backup files replaced
# alternatively use ksh so test -e works on 502 
 
SSE="sse072c"
 if /bin/strings -a /usr/lib/libc.so.1 | grep -q strlcpy; then
        ENFORCE_RUNLEVEL=0
 else
        ENFORCE_RUNLEVEL=1
 fi  

chk_runlevel()
{

set `who -r`
case $3 in 
    1 | S)
        ;;
    *)
        echo "$SSE NOT installed:\nYou must be running in Single User mode to install this SSE"
        exit 1
        ;;
esac    
}

echo "ENFORCE_RUNLEVEL: $ENFORCE_RUNLEVEL"
echo "You are about to install $SSE."
echo "If you proceed, documentation will be displayed, followed by"
echo "  another chance to cancel installation of ${SSE}."
echo "Press enter to proceed, or break now to cancel."
read uio

SRCDIR=`pwd`

# uname -v returns 2 (3.2) for osr5 before 5.0.5
# VER=`uname -v`
#expr "${VER}" : '5.0.[0-5]' >/dev/null
#[ "$?" -eq 0 -o "$VER" = "2" ] || {
#	echo "$SSE NOT installed, it can only be installed on OpenServer 5.0.5."
#	exit
#}

UNIX_SSO=`ls -d /opt/K/SCO/Unix/5.0.[0-6][A-Z][a-z]`

if [ ! -f ${SSE}.doc ]; then
	echo "${SSE} NOT installed, you must have ${SSE}.doc in the current directory."
	exit
fi

if [ ! -f ${SSE}.files.tar ]; then
	echo "${SSE} NOT installed, ${SSE}.files.tar must exist in the current directory."
	exit
fi

if [ ! `id -u` -eq '0' ] ; then 
	echo "${SSE} NOT installed, must be running as root to install."
fi

# also use ENFORCE_RUNLEVEL now to install libc.so.1
[ "$ENFORCE_RUNLEVEL" -eq 1 ] && chk_runlevel


/usr/bin/more -e ${SSE}.doc

echo
echo "To continue installation, press enter.  Break now to cancel."
read uio


# [ -e ]  not avail in sh 502 and prior - use -f in that case
#tf='-e'
#[ -n `test $tf /unix 2>&1` ] &&  tf='-f'
# Just use -f in all cases 
tf='-f'

echo "Backing up and installing now..."
echo

umask 077

cd /

if [ -d /opt/K/SCO/sse/${SSE} ]; then
	echo
	echo ${SSE} NOT installed.
	echo 
	echo It appears that this patch has already been installed.
	echo If this patch failed during a previous attempt, please
	echo copy the original binaries out of the backup directory,
	echo /opt/K/SCO/sse/${SSE}, and replace them in the original
	echo locations.  If you do not, the original copies of the
	echo binaries could be overwritten.
	exit
fi

mkdir -p /opt/K/SCO/sse/${SSE}

TARFILE=${SRCDIR}/${SSE}.files.tar
for backup_file in `/usr/bin/tar tf ${TARFILE}`; do
# version-specific checking not currently used for libraries
#       [ "$VER" = 5.0.6 -a \( "$backup_file" = usr/lib/libsocket.so.2 -o \
#               "$backup_file" = usr/lib/libresolv.so.1 \) ] && continue
        [ "$backup_file" = usr/lib/libsocket.so.2 -a \
                           -f /usr/lib/libsocket.so.2 ] && continue
        [ "$backup_file" = usr/lib/libresolv.so.1 -a \
                           -f /usr/lib/libsocket.so.1 ] && continue
        [ "$backup_file" = usr/lib/libc.so.1 -a \
                           "$ENFORCE_RUNLEVEL" -eq 0 ] && continue

	backup_dir=`/bin/dirname $backup_file`;

	if [ ! -d /opt/K/SCO/sse/${SSE}/backup/${backup_dir} ]; then
		mkdir -p /opt/K/SCO/sse/${SSE}/backup/${backup_dir}
	fi

	# Replace only files that exist on the system.

        # There is a special procedure for replacing libc ONLY

	if [ ${tf} "${backup_file}" ]; then
		cp ${backup_file} /opt/K/SCO/sse/${SSE}/backup/${backup_dir}
                if [ "$backup_file" = usr/lib/libc.so.1 ]; then
	 	   (cd /tmp && /usr/bin/tar xvf ${TARFILE} ${backup_file} \
                                  2>/dev/null)
                   chmod 555 /tmp/${backup_file}
                   chown bin:bin /tmp/${backup_file}
                   mv -f /tmp/${backup_file} ${UNIX_SSO}/usr/lib 
                else
		   cp ${backup_file} /opt/K/SCO/sse/${SSE}/backup/${backup_dir}
		   (cd / && /usr/bin/tar xvf ${TARFILE} ${backup_file} \
                                  2>/dev/null)
                fi
	else
		echo "WARNING: ${backup_file} not replaced; it did not exist or not a file."
	fi
done

chmod 700 /opt/K/SCO/sse
chmod -R 0 /opt/K/SCO/sse/${SSE}

[ -f $INSTDIR/postinstall-${SSE}.sh ] && {
    SSE_FORKED='YES' 
     . $INSTDIR/postinstall-${SSE}.sh
}

echo
echo "Installation complete."
echo 
echo "If you need any to undo the changes made by this SSE, original files"
echo "are located in the /opt/K/SCO/sse/${SSE} directory.  "
echo "PLEASE NOTE: If a backup of /usr/lib/libc.so.1 exists, and you wish"
echo "to restore this file, care must be taken; perform the following" 
echo "commands, in single user mode:"
echo 
echo "cd /usr/lib"
echo "cp libc.so.1 libc.so.1.new"
echo "cd /opt/K/SCO/sse/${SSE}/usr/lib"
echo "chmod 555 libc.so.1"
echo "cp libc.so.1 libc.so.1.orig"
echo "mv -f libc.so.1 ${UNIX_SSO}"
echo
echo "The above procedure saves copies of both new and original versions"
echo "of libc.so.1" 
echo
echo "The Software Manager - custom - can be used to fix the permissions on "
echo " these files after they have been restored to their original locations."
echo

